@@ -75,8 +75,9 @@
 #' @param na.rm logical indicating whether NA's should be removed.
 #'
 #' @param digits integer indicating the number of decimal places to be used by \link{round} for 'label'.
-#' @param cellnote (optional) matrix of the same dimensions as \code{x} that has the human-readable version of each value, for displaying to the user on hover. If \code{NULL}, then \code{x} will be coerced using \code{\link{as.character}}.
-#' If missing, it will use \code{x}, after rounding it based on the \code{digits} parameter.
+#' @param cellnote (optional) matrix of the same dimensions as \code{x}
+#' that has the human-readable version of each value,
+#' for displaying on top of the heatmap cells.
 #'
 #' @param cexRow positive numbers. If not missing, it will override \code{xaxis_font_size}
 #' and will give it a value cexRow*14
@@ -455,6 +456,11 @@ heatmapr <- function(x,
   ## Final touches before exporting the object
   ## =======================
 
+  # if(!is.null(custom_hovertext) && !is.matrix(custom_hovertext)) {
+  if(is.data.frame(custom_hovertext)) {
+      custom_hovertext <- as.matrix(custom_hovertext)
+  }
+
   mtx <- list(
     data = as.matrix(x),
     cellnote = cellnote,
